@@ -1,6 +1,6 @@
 from enum import Enum
 from typing import Optional
-from common import GraphBase
+from .common import GraphBase
 
 
 class DelayType(Enum):
@@ -287,4 +287,4 @@ class DelayGraph(GraphBase):
 
     @staticmethod
     def parse(inputFile: str):
-        return DelayGraph(Delay.parse(inputFile))
\ No newline at end of file
+        return DelayGraph(Delay.parse(inputFile))
