@@ -1,7 +1,6 @@
-import random
 from enum import Enum
 from typing import Optional
-from common import GraphBase
+from .common import GraphBase
 
 
 class ThroughputType(Enum):
@@ -116,6 +115,12 @@ class NodeFaceThroughput:
         self.typeMap[item.Type.name].append(item)
 
     def getX(self, throughputType: ThroughputType = ThroughputType.OutData, samplingInterval: float = 1.0):
+        """
+        获取采样时间列表
+        :param throughputType:
+        :param samplingInterval:
+        :return:
+        """
         lastCount, res = 0, []
         for item in self.typeMap[throughputType.name]:
             if int(item.Time / samplingInterval) != lastCount:
@@ -169,6 +174,13 @@ class NodeThroughput:
 
     def getX(self, FaceId: int, throughputType: ThroughputType = ThroughputType.OutData,
              samplingInterval: float = 1.0) -> [float]:
+        """
+        获取采样时间列表
+        :param FaceId:
+        :param throughputType:
+        :param samplingInterval:
+        :return:
+        """
         if FaceId not in self.faceIdMap:
             return []
         return self.faceIdMap[FaceId].getX(throughputType, samplingInterval)
@@ -227,15 +239,6 @@ class Throughput:
         return throughput
 
 
-def getRandomColor():
-    """获取一个随机的颜色"""
-    colorArr = ['1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', 'B', 'C', 'D', 'E', 'F']
-    color = ""
-    for i in range(6):
-        color += colorArr[random.randint(0, 14)]
-    return "#" + color
-
-
 class ThroughputGraph(GraphBase):
     """
     一个用于实现绘制吞吐量图的类
